@@ -7,7 +7,7 @@ package Dist::Zilla::PluginBundle::Author::KENTNL;
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
 
-our $VERSION = '2.015000';
+our $VERSION = '2.016000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -136,7 +136,7 @@ use namespace::autoclean;
 
 
 
-sub mvp_multivalue_args { return qw( auto_prereqs_skip ) }
+sub mvp_multivalue_args { return qw( auto_prereqs_skip copyfiles ) }
 
 
 
@@ -361,6 +361,40 @@ has 'bumpversions' => (
 
 
 
+
+
+
+
+
+
+has copyfiles => (
+  is      => ro  =>,
+  isa     => 'ArrayRef[ Str ]',
+  lazy    => 1,
+  builder => sub { [] },
+);
+
+
+
+
+
+
+
+
+
+has srcreadme => (
+  is => ro =>,
+  isa => enum( [ 'pod', 'mkdn', 'none' ] ),
+  lazy    => 1,
+  builder => sub { return 'mkdn'; },
+);
+
+
+
+
+
+
+
 sub add_plugin {
   my ( $self, $suffix, $conf ) = @_;
   if ( not defined $conf ) {
@@ -437,12 +471,27 @@ sub _configure_basic_metadata {
 }
 
 sub _configure_basic_files {
-  my ($self) = @_;
-  $self->add_plugin( 'Git::GatherDir' => { include_dotfiles => 1 } );
-  $self->add_plugin( 'License'        => {} );
-  $self->add_plugin( 'MetaJSON'       => {} );
-  $self->add_plugin( 'MetaYAML'       => {} );
-  $self->add_plugin( 'Manifest'       => {} );
+  my ($self)         = @_;
+  my (@ignore_files) = qw( README README.mkdn README.pod );
+
+  push @ignore_files, @{ $self->copyfiles };
+
+  $self->add_plugin(
+    'Git::GatherDir' => {
+      include_dotfiles => 1,
+      exclude_filename => [@ignore_files],
+    },
+  );
+  $self->add_plugin( 'License' => {} );
+
+  $self->add_plugin( 'MetaJSON' => {} );
+  $self->add_plugin( 'MetaYAML' => {} );
+  $self->add_plugin( 'Manifest' => {} );
+
+  if ( @{ $self->copyfiles } ) {
+    $self->add_named_plugin( 'CopyXBuild' => 'CopyFilesFromBuild', { copy => [ @{ $self->copyfiles } ] } );
+  }
+
   return;
 }
 
@@ -564,6 +613,29 @@ sub _configure_toolkit_prereqs {
   return;
 }
 
+sub _configure_readmes {
+  my ($self) = @_;
+
+  $self->add_plugin( 'ReadmeFromPod' => {} );
+
+  my $type = $self->srcreadme;
+
+  return if 'none' eq $type;
+
+  my $map = {};
+  $map->{mkdn} = { type => 'markdown', filename => 'README.mkdn' };
+  $map->{pod}  = { type => 'pod',      filename => 'README.pod' };
+
+  if ( not exists $map->{$type} ) {
+    require Carp;
+    return Carp::confess("No known readme type $type");
+  }
+
+  $self->add_plugin( 'ReadmeAnyFromPod' => { location => 'root', %{ $map->{$type} } }, );
+
+  return;
+}
+
 sub configure {
   my ($self) = @_;
 
@@ -612,14 +684,8 @@ sub configure {
 
   $self->_configure_toolkit;
 
-  $self->add_plugin( 'ReadmeFromPod' => {} );
-  $self->add_plugin(
-    'ReadmeAnyFromPod' => {
-      type     => 'markdown',
-      filename => 'README.mkdn',
-      location => 'root',
-    },
-  );
+  $self->_configure_readmes;
+
   $self->add_plugin( 'Test::CPAN::Changes' => {} );
   $self->add_plugin( 'RunExtraTests'       => { default_jobs => 10 } );
   $self->add_plugin( 'TestRelease'         => {} );
@@ -687,7 +753,7 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 2.015000
+version 2.016000
 
 =head1 SYNOPSIS
 
@@ -908,6 +974,22 @@ Determines which tooling to generate the distribution with
 If true, use C<[BumpVersionAfterRelease]>  and C<[RewriteVersions::Sanitized]> instead of C<[PkgVersion]> and
 C<[Git::NextVersion::Sanitized]>
 
+=head2 C<copyfiles>
+
+An array of files generated by C<Dist::Zilla> build to copy from the built dist back to the source dist
+
+  copyfiles = LICENSE
+  ; Warning: These two are presently bad ideas
+  ; and will ultimately give version mismatches
+  copyfiles = Makefile.PL
+  copyfiles = META.json
+
+=head2 C<srcreadme>
+
+  srcreadme = pod  ; # generate README.pod on the source side
+  srcreadme = mkdn ; # generate README.mkdn on the source side
+  srcreadme = none ; # don't generate README on the source side
+
 =begin MetaPOD::JSON v1.1.0
 
 {
